@@ -173,12 +173,6 @@ const typename sga_statics<T>::mutation_map_t sga_statics<T>::m_mutation_map = i
  *    Most genetic operators use the lower and upper bound information. Hence, unbounded problems will produce undefined
  *    behaviours.
  *
- * .. note::
- *
- *    Specifying the parameter ``int_dim`` a part of the decision vector (at the end) will be treated as integers
- *    This means that all genetic operators are guaranteed to produce integer decision vectors in the specified bounds.
- *    The various mutation and crossover strategies will do different things on an integer gene or a real valued one.
- *
  * .. seealso::
  *
  *    Oliveto, Pietro S., Jun He, and Xin Yao. "Time complexity of evolutionary algorithms for
@@ -229,8 +223,9 @@ public:
           m_verbosity(0u), m_log()
     {
         if (cr > 1. || cr < 0.) {
-            pagmo_throw(std::invalid_argument, "The crossover probability must be in the [0,1] range, while a value of "
-                                                   + std::to_string(cr) + " was detected");
+            pagmo_throw(std::invalid_argument,
+                        "The crossover probability must be in the [0,1] range, while a value of " + std::to_string(cr)
+                            + " was detected");
         }
         if (eta_c < 1. || eta_c > 100.) {
             pagmo_throw(std::invalid_argument,
@@ -238,12 +233,14 @@ public:
                             + std::to_string(eta_c) + " was detected");
         }
         if (m < 0. || m > 1.) {
-            pagmo_throw(std::invalid_argument, "The mutation probability must be in the [0,1] range, while a value of "
-                                                   + std::to_string(cr) + " was detected");
+            pagmo_throw(std::invalid_argument,
+                        "The mutation probability must be in the [0,1] range, while a value of " + std::to_string(cr)
+                            + " was detected");
         }
         if (param_s == 0u) {
-            pagmo_throw(std::invalid_argument, "The selection parameter must be at least 1, while a value of "
-                                                   + std::to_string(param_s) + " was detected");
+            pagmo_throw(std::invalid_argument,
+                        "The selection parameter must be at least 1, while a value of " + std::to_string(param_s)
+                            + " was detected");
         }
         if (mutation != "gaussian" && mutation != "uniform" && mutation != "polynomial") {
             pagmo_throw(
@@ -265,15 +262,17 @@ public:
         }
         // param_m represents the distribution index if polynomial mutation is selected
         if (mutation == "polynomial" && (param_m < 1. || param_m > 100.)) {
-            pagmo_throw(std::invalid_argument, "Polynomial mutation was selected, the mutation parameter (distribution "
-                                               "index) must be in [1, 100], while a value of "
-                                                   + std::to_string(param_m) + " was detected");
+            pagmo_throw(std::invalid_argument,
+                        "Polynomial mutation was selected, the mutation parameter (distribution "
+                        "index) must be in [1, 100], while a value of "
+                            + std::to_string(param_m) + " was detected");
         }
 
         // otherwise param_m represents the width of the mutation relative to the box bounds
         if (mutation != "polynomial" && (param_m < 0 || param_m > 1.)) {
-            pagmo_throw(std::invalid_argument, "The mutation parameter must be in [0,1], while a value of "
-                                                   + std::to_string(param_m) + " was detected");
+            pagmo_throw(std::invalid_argument,
+                        "The mutation parameter must be in [0,1], while a value of " + std::to_string(param_m)
+                            + " was detected");
         }
         // We can now init the data members representing the various choices made using std::string
         m_crossover = m_crossover_map.left.at(crossover);
@@ -289,8 +288,7 @@ public:
      * @return evolved population
      * @throws std::invalid_argument if the problem is multi-objective or constrained, if the population size is smaller
      * than 2, if \p param_s is larger than the population size, if the size of \p pop is odd and a "sbx" crossover has
-     * been selected upon construction, if the problem dimension is smaller than the \p int_dim chosen upon
-     * construction.
+     * been selected upon construction.
      */
     population evolve(population pop) const
     {
@@ -303,22 +301,25 @@ public:
         // PREAMBLE-------------------------------------------------------------------------------------------------
         // Check whether the problem/population are suitable for bee_colony
         if (prob.get_nc() != 0u) {
-            pagmo_throw(std::invalid_argument, "Constraints detected in " + prob.get_name() + " instance. " + get_name()
-                                                   + " cannot deal with them");
+            pagmo_throw(std::invalid_argument,
+                        "Constraints detected in " + prob.get_name() + " instance. " + get_name()
+                            + " cannot deal with them");
         }
         if (prob.get_nf() != 1u) {
-            pagmo_throw(std::invalid_argument, "Multiple objectives detected in " + prob.get_name() + " instance. "
-                                                   + get_name() + " cannot deal with them");
+            pagmo_throw(std::invalid_argument,
+                        "Multiple objectives detected in " + prob.get_name() + " instance. " + get_name()
+                            + " cannot deal with them");
         }
         if (NP < 2u) {
-            pagmo_throw(std::invalid_argument, prob.get_name() + " needs at least 2 individuals in the population, "
-                                                   + std::to_string(NP) + " detected");
+            pagmo_throw(std::invalid_argument,
+                        prob.get_name() + " needs at least 2 individuals in the population, " + std::to_string(NP)
+                            + " detected");
         }
         if (m_param_s > pop.size()) {
             pagmo_throw(std::invalid_argument,
                         "The parameter for selection must be smaller than the population size, while a value of: "
-                            + std::to_string(m_param_s) + " was detected in a population of size: "
-                            + std::to_string(pop.size()));
+                            + std::to_string(m_param_s)
+                            + " was detected in a population of size: " + std::to_string(pop.size()));
         }
         if (m_crossover == crossover::SBX && (pop.size() % 2 != 0u)) {
             pagmo_throw(std::invalid_argument,
@@ -373,8 +374,8 @@ public:
 
                     // Every 50 lines print the column names
                     if (count % 50u == 1u) {
-                        print("\n", std::setw(7), "Gen:", std::setw(15), "Fevals:", std::setw(15), "Best:",
-                              std::setw(15), "Improvement:", '\n');
+                        print("\n", std::setw(7), "Gen:", std::setw(15), "Fevals:", std::setw(15),
+                              "Best:", std::setw(15), "Improvement:", '\n');
                     }
                     print(std::setw(7), i, std::setw(15), prob.get_fevals() - fevals0, std::setw(15),
                           pop.get_f()[pop.best_idx()][0], std::setw(15), improvement, '\n');
